@@ -3,7 +3,7 @@
  *   stuff common to chan.c and mode.c
  *   users.h needs to be loaded too
  *
- * $Id: chan.h,v 1.39 2004/01/09 05:56:36 wcc Exp $
+ * $Id: chan.h,v 1.40 2004/06/27 17:26:51 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
@@ -125,7 +125,7 @@ struct chan_t {
   masklist *invite;
   char *topic;
   char *key;
-  unsigned short int mode;
+  unsigned int mode;
   int maxmembers;
   int members;
 };
@@ -145,6 +145,10 @@ struct chan_t {
 #define CHANMODREG 0x1000  /* M - Bahamut              */
 #define CHANNOCTCP 0x2000  /* C - QuakeNet's ircu 2.10 */
 #define CHANLONLY  0x4000  /* r - ircu 2.10.11         */
+#define CHANDELJN  0x8000  /* D - QuakeNet's asuka     */
+#define CHANSTRIP  0x10000 /* u - QuakeNet's asuka     */
+#define CHANNONOTC 0x20000 /* N - QuakeNet's asuka     */
+#define CHANINVIS  0x40000 /* d - QuakeNet's asuka     */
 
 struct chanset_t {
   struct chanset_t *next;
@@ -249,6 +253,7 @@ struct chanset_t *findchan_by_dname(const char *name);
 
 #define channel_hidden(chan) (chan->channel.mode & (CHANPRIV | CHANSEC)) /* +s or +p ? */
 #define channel_optopic(chan) (chan->channel.mode & CHANTOPIC) /* +t? */
+#define channel_djoins(chan) (chan->status & (CHANDELJN | CHANINVIS)) /* +Dd? */
 
 #define channel_active(chan)  (chan->status & CHAN_ACTIVE)
 #define channel_pending(chan)  (chan->status & CHAN_PEND)
