@@ -2,7 +2,7 @@
  * chancmds.c -- part of irc.mod
  *   handles commands directly relating to channel interaction
  *
- * $Id: cmdsirc.c,v 1.56 2004/01/09 05:56:38 wcc Exp $
+ * $Id: cmdsirc.c,v 1.57 2004/06/03 14:10:18 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
@@ -533,7 +533,8 @@ static void cmd_voice(struct userrec *u, int idx, char *par)
    * If you are... not a (channel op, or a channel half op, or a global op
    * without channel deop, or a global halfop without channel dehalfop)...
    * - stdarg */
-  if (m && !(chan_op(user) || chan_halfop(user) || (glob_op(user) && !chan_deop(user)) || (glob_halfop(user) && !chan_dehalfop(user)))) {
+  if (m && !(chan_op(user) || chan_halfop(user) || (glob_op(user) &&
+      !chan_deop(user)) || (glob_halfop(user) && !chan_dehalfop(user)))) {
     egg_snprintf(s, sizeof s, "%s!%s", m->nick, m->userhost);
     u2 = m->user ? m->user : get_user_by_host(s);
 
@@ -586,7 +587,8 @@ static void cmd_devoice(struct userrec *u, int idx, char *par)
 
   get_user_flagrec(dcc[idx].user, &user, chan->dname);
   m = ismember(chan, nick);
-  if (m && !(chan_op(user) || chan_halfop(user) || (glob_op(user) && !chan_deop(user)) || (glob_halfop(user) && !chan_dehalfop(user)))) {
+  if (m && !(chan_op(user) || chan_halfop(user) || (glob_op(user) &&
+      !chan_deop(user)) || (glob_halfop(user) && !chan_dehalfop(user)))) {
     egg_snprintf(s, sizeof s, "%s!%s", m->nick, m->userhost);
     u2 = m->user ? m->user : get_user_by_host(s);
 
@@ -1178,6 +1180,6 @@ static cmd_t irc_dcc[] = {
   {"kickban",      "lo|lo", (Function) cmd_kickban,      NULL},
   {"msg",          "o",     (Function) cmd_msg,          NULL},
   {"say",          "o|o",   (Function) cmd_say,          NULL},
-  {"topic",        "lo|lo",   (Function) cmd_topic,        NULL},
+  {"topic",        "lo|lo", (Function) cmd_topic,        NULL},
   {NULL,           NULL,    NULL,                        NULL}
 };
