@@ -1,10 +1,10 @@
 /*
  * transfer.c -- part of transfer.mod
  *
- * $Id: transfer.c,v 1.66 2003/04/17 01:55:57 wcc Exp $
+ * $Id: transfer.c,v 1.69 2004/01/09 05:56:39 wcc Exp $
  *
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999, 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -967,10 +967,6 @@ static void dcc_get_pending(int idx, char *buf, int len)
  * `filename' from `dir'.
  *
  * Use raw_dcc_resend() and raw_dcc_send() instead of this function.
- *
- * This function is NOT fully IPv6 capable, the DCC CHAT/SEND specs for
- * IPv6 aren't clear between all the different clients, but irssi and
- * KSIRC(?) appear to use the IPv6 in the 'long' format (hex w/o colons)
  * 
  */
 static int raw_dcc_resend_send(char *filename, char *nick, char *from,
@@ -983,6 +979,8 @@ static int raw_dcc_resend_send(char *filename, char *nick, char *from,
 
   zz = -1;
   dccfile = fopen(filename, "r");
+  if (!dccfile)
+    return DCCSEND_BADFN;
   fseek(dccfile, 0, SEEK_END);
   dccfilesize = ftell(dccfile);
   fclose(dccfile);
@@ -992,19 +990,11 @@ static int raw_dcc_resend_send(char *filename, char *nick, char *from,
 
   if (reserved_port_min > 0 && reserved_port_min < reserved_port_max) {
     for (port = reserved_port_min; port <= reserved_port_max; port++)
-#ifdef USE_IPV6
-      if ((zz = open_listen_by_af(&port, AF_INET6)) != -1) /* no idea how we want to handle this -poptix 02/03/03 */
-#else
       if ((zz = open_listen(&port)) != -1)
-#endif /* USE_IPV6 */
         break;
   } else {
     port = reserved_port_min;
-#ifdef USE_IPV6
-    zz = open_listen_by_af(&port, AF_INET6);
-#else
     zz = open_listen(&port);
-#endif /* USE_IPV6 */
   }
 
   if (zz == -1)
