@@ -7,7 +7,7 @@
  * because they use structures in those
  * (saves including those .h files EVERY time) - Beldin
  *
- * $Id: proto.h,v 1.62 2004/01/09 12:07:22 wcc Exp $
+ * $Id: proto.h,v 1.63 2004/06/14 01:14:06 wcc Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
@@ -35,7 +35,7 @@
 #include "misc_file.h"
 
 #ifdef HAVE_DPRINTF
-#define dprintf dprintf_eggdrop
+#  define dprintf dprintf_eggdrop
 #endif
 
 struct chanset_t;               /* keeps the compiler warnings down :) */
@@ -46,7 +46,7 @@ struct flag_record;
 struct list_type;
 struct tand_t_struct;
 
-#if !defined(MAKING_MODS)
+#ifndef MAKING_MODS
 extern void (*encrypt_pass) (char *, char *);
 extern char *(*encrypt_string) (char *, char *);
 extern char *(*decrypt_string) (char *, char *);
